<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="50%"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.rules"    >
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="企业名称:" prop="companyId" v-if="state.isAdmin">
              <el-select v-model="state.form.companyId" placeholder="请选择" clearable style="width: 100%" :disabled="title == '查看' || title == '编辑' || !state.isAdmin" @change="selectValueCom">
                <el-option
                    v-for="item in state.companyList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="质量目标:" prop="qualityId" >
              <el-select
                  :disabled="title === '查看' || title == '编辑'"
                  v-model="state.form.qualityId"
                  placeholder="请选择质量目标"
                  style="width: 100%"
                  @change="chooseQuality"
              >
                <el-option
                    v-for="item in state.qualityList"
                    :key="item.id"
                    :label="item.message"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="编号:" prop="number" >
              <el-input :disabled="title === '查看'" v-model="state.form.number" placeholder="请输入编号" style="width: 100%"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <span style="font-size: 15px;font-weight: 700;" >公司级质量目标分解表:</span>
            <el-table style="margin-top: 10px;margin-bottom: 20px" :data="state.form.qualityTargets" :border="true">
              <el-table-column type="index" label="序号"  align="center"></el-table-column>
              <el-table-column label="目标项目" prop="message" align="center"  />
              <el-table-column label="目标展开" align="center"  >
                <template #default="{row,$index}">
                  <el-form-item :prop="'qualityTargets.' + '[' + $index + ']' + '.method'" :rules="state.rules.method">
                    <el-input :disabled="title === '查看'" type="textarea" v-model="row.method" placeholder="请输入"></el-input>
                  </el-form-item>
                </template>
              </el-table-column>
              <el-table-column label="实施对策" align="center"  >
                <template #default="{row,$index}">
                  <el-form-item :prop="'qualityTargets.' + '[' + $index + ']' + '.calculate'" :rules="state.rules.calculate">
                    <el-input :disabled="title === '查看'"  type="textarea" v-model="row.calculate" placeholder="请输入"></el-input>
                  </el-form-item>
                </template>
              </el-table-column>
              <el-table-column label="责任人" align="center"  >
                <template #default="{row,$index}">
                  <el-form-item :prop="'qualityTargets.' + '[' + $index + ']' + '.dutyName'" :rules="state.rules.dutyName">
                    <el-input :disabled="title === '查看'"  type="textarea" v-model="row.dutyName" placeholder="请输入"></el-input>
                  </el-form-item>
                </template>
              </el-table-column>
              <el-table-column label="考核时机" align="center"  >
                <template #default="{row,$index}">
                  <el-form-item :prop="'qualityTargets.' + '[' + $index + ']' + '.frequency'" :rules="state.rules.frequency">
                    <el-input :disabled="title === '查看'"  type="textarea" v-model="row.frequency" placeholder="请输入"></el-input>
                  </el-form-item>
                </template>
              </el-table-column>
              <el-table-column label="备注" align="center"  >
                <template #default="{row,$index}">
                  <el-form-item :prop="'qualityTargets.' + '[' + $index + ']' + '.remark'">
                    <el-input :disabled="title === '查看'"  type="textarea" v-model="row.remark" placeholder="请输入"></el-input>
                  </el-form-item>
                </template>
              </el-table-column>
            </el-table>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="编制:" prop="fictionId" >
              <el-select clearable v-model="state.form.fictionId" :disabled="title =='查看'" filterable  style="width: 100%">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="日期:" prop="fictionTime" >
              <el-date-picker
                  :disabled="title === '查看'"
                  v-model="state.form.fictionTime"
                  type="date"
                  placeholder="请选择日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24" >
          <el-col :span="12">
            <el-form-item label="审核:" prop="checkId" >
              <el-select clearable v-model="state.form.checkId" :disabled="title =='查看'" filterable  style="width: 100%">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="日期:" prop="checkTime" >
              <el-date-picker
                  :disabled="title === '查看'"
                  v-model="state.form.checkTime"
                  type="date"
                  placeholder="请选择日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="批准(公司分管领导):" prop="ratifyId" >
              <el-select clearable v-model="state.form.ratifyId" :disabled="title =='查看'" filterable  style="width: 100%">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="日期:" prop="ratifyTime" >
              <el-date-picker
                  :disabled="title === '查看'"
                  v-model="state.form.ratifyTime"
                  type="date"
                  placeholder="请选择日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer v-if="title !== '查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {onMounted, reactive, ref, toRefs} from 'vue'
import Cookies from "js-cookie";
import {getCompany} from "@/api/onlineEducation/company";
import {ElMessage} from "element-plus";
import {getUser} from "@/api/onlineEducation/user";
import {getObject, getObjectPage} from "@/api/qualityObjectives/object";
import {addTable, editTable, getTargetById} from "@/api/qualityObjectives/table";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const dataRef = ref();
const state = reactive({
  form: {
    id: '',
    qualityId: '',
    number: '',
    serial: '',
    fictionId : '',
    fictionName: '',
    fictionTime:'',
    checkId :'',
    checkName: '',
    checkTime:'',
    ratifyId:'',
    ratifyName: '',
    ratifyTime: '',
    qualityTargets:[],
  },
  rules: {
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    qualityId: [{ required: true, message: '请选择质量目标', trigger: 'blur' }],
    number: [{ required: true, message: '请输入编号', trigger: 'blur' }],
    serial: [{ required: true, message: '请输入序号', trigger: 'blur' }],
    fictionId: [{ required: true, message: '请选择拟制', trigger: 'blur' }],
    ratifyId: [{ required: true, message: '请选择批准人', trigger: 'blur' }],
    checkId: [{ required: true, message: '请选择审核人', trigger: 'blur' }],
    checkTime: [{ required: true, message: '请选择日期', trigger: 'blur' }],
    ratifyTime: [{ required: true, message: '请选择日期', trigger: 'blur' }],
    fictionTime: [{ required: true, message: '请选择日期', trigger: 'blur' }],
    dutyName: [{required: true, message: "", trigger: "blur"}],
    method: [{required: true, message: "", trigger: "blur"}],
    calculate: [{required: true, message: "", trigger: "blur"}],
    dataSource: [{required: true, message: "", trigger: "blur"}],
    departName: [{required: true, message: "", trigger: "blur"}],
    frequency: [{required: true, message: "", trigger: "blur"}],
  },
  objectList: [],
  qualityList: [],
  peopleList: [],
  isAdmin: false,
  companyList: [],
})

onMounted(() => {


});
const openDialog = async (type, value,companyList) => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  state.isAdmin = userInfo.userType === 0;
  state.form.companyName = userInfo.companyName
  state.form.companyId = userInfo.companyId
  if(state.isAdmin){
    state.form.companyId = value.companyId
    state.form.companyName = value.companyName
    state.companyList = companyList
  }

    await getQualityList()

  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
  if(type === 'edit' || type === 'review') {
    state.form = JSON.parse(JSON.stringify(value));
  }

  await   getPeopleList()
  dialogVisible.value = true;
}

const getQualityList = async () => {
  if(state.form.companyId){
    const res = await getObject({companyId:state.form.companyId,type: 2 });
    if(res.code === 200){
      state.qualityList = res.data.data.map(item => {
        return {
          ...item,
          message: item.qualityTargets.map((i,index) => {
            return  i.message
          }).join(';')
        }
      })
    }else{
      ElMessage.warning(res.message)
    }
  }else {
    state.qualityList = []
  }


}
const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      console.log('sta',state.form)
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addTable(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editTable(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    qualityId: '',
    number: '',
    serial: '',
    fictionId : '',
    fictionName: '',
    fictionTime:'',
    checkId :'',
    checkName: '',
    checkTime:'',
    ratifyId:'',
    ratifyName: '',
    ratifyTime: '',
    qualityTargets:[],
  }
  state.peopleList = []
  state.companyList = []
}
const getPeopleList = async ()=> {
  if(state.isAdmin && (state.form.companyId == 0 || state.form.companyId == null)){
    return
  }
  const queryParams = {
    pageNum: 1,
    pageSize: 9999,
    companyId: state.form.companyId
  }
  const res = await getUser(queryParams)
  if(res.code == 200){
    state.peopleList = res.data.list?res.data.list:[]
  }else{
    ElMessage.warning(res.message)
  }
};
const selectValue = (val) => {
  state.peopleList.forEach(item => {
    if(item.name === val){
      state.form.fictionId = item.id
    }
  })
}
const selectValue1 = (val) => {
  state.peopleList.forEach(item => {
    if(item.name === val){
      state.form.checkId  = item.id
    }
  })
}
const selectValue2 = (val) => {
  state.peopleList.forEach(item => {
    if(item.name === val){
      state.form.ratifyId = item.id
    }
  })
}

const chooseQuality = async (val) => {
  const res = await getTargetById({qualityId: val})
  if(res.code == 200){
    state.form.qualityTargets = res.data.map(item => {
      return {
        id: item.id,
        message: item.message
      }
    })

  }else {
    ElMessage.warning(res.message)
  }
  console.log('val',val)

}
const selectValueCom = (val) => {
  state.form.qualityId = null
  state.qualityList = []
  state.form.qualityTargets = []
  state.form.fictionId = null
  state.form.fictionName = ''
  state.form.checkId = null
  state.form.checkName = ''
  state.form.ratifyId = null
  state.form.ratifyName = ''
  state.companyList.forEach(item => {
    if(item.name === val){
      state.form.companyId = item.id
    }
  })
  getQualityList()
  getPeopleList()
}

defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
